@@ -18,16 +18,25 @@
 
 #[cfg(any(
     all(feature = "native-roots", feature = "webpki-roots"),
-    not(any(feature = "native-roots", feature = "webpki-roots")),
+    all(feature = "native-roots", feature = "native-tls"),
+    all(feature = "webpki-roots", feature = "native-tls"),
+    not(any(
+        feature = "native-roots",
+        feature = "webpki-roots",
+        feature = "native-tls"
+    )),
 ))]
 compile_error!(
-    "exactly one of feature \"native-roots\" and feature \"webpki-roots\" must be enabled"
+    "exactly one of the features \"native-roots\", \"webpki-roots\" or \"native-tls\" must be enabled"
 );
 
-use std::{env, process};
+use std::{
+    env,
+    io::{self, IsTerminal},
+    process,
+};
 
 use app_dirs::AppInfo;
-use atty::Stream;
 use clap::Parser;
 
 mod cache;
@@ -42,7 +51,7 @@ mod utils;
 
 use crate::{
     cache::{Cache, CacheFreshness, PageLookupResult, TLDR_PAGES_DIR},
-    cli::Args,
+    cli::Cli,
     config::{get_config_dir, get_config_path, make_default_config, Config, PathWithSource},
     extensions::Dedup,
     output::print_page,
@@ -59,7 +68,7 @@ const ARCHIVE_URL: &str = "https://tldr.sh/assets/tldr.zip";
 
 /// The cache should be updated if it was explicitly requested,
 /// or if an automatic update is due and allowed.
-fn should_update_cache(cache: &Cache, args: &Args, config: &Config) -> bool {
+fn should_update_cache(cache: &Cache, args: &Cli, config: &Config) -> bool {
     args.update
         || (!args.no_auto_update
             && config.updates.auto_update
@@ -75,7 +84,7 @@ enum CheckCacheResult {
 }
 
 /// Check the cache for freshness. If it's stale or missing, show a warning.
-fn check_cache(cache: &Cache, args: &Args, enable_styles: bool) -> CheckCacheResult {
+fn check_cache(cache: &Cache, args: &Cli, enable_styles: bool) -> CheckCacheResult {
     match cache.freshness() {
         CacheFreshness::Fresh => CheckCacheResult::CacheFound,
         CacheFreshness::Stale(_) if args.quiet => CheckCacheResult::CacheFound,
@@ -104,7 +113,7 @@ fn check_cache(cache: &Cache, args: &Args, enable_styles: bool) -> CheckCacheRes
             println!("The path to your config file can be looked up with `tldr --show-paths`.");
             println!("To create an initial config file, use `tldr --seed-config`.\n");
             println!("You can find more tips and tricks in our docs:\n");
-            println!("  https://dbrgn.github.io/tealdeer/config_updates.html");
+            println!("  https://tealdeer-rs.github.io/tealdeer/config_updates.html");
             CheckCacheResult::CacheMissing
         }
     }
@@ -119,12 +128,9 @@ fn clear_cache(cache: &Cache, quietly: bool, enable_styles: bool) {
     if !quietly {
         let cache_dir = cache.cache_dir().display();
         if cache_dir_found {
-            eprintln!("Successfully cleared cache at `{}`.", cache_dir);
+            eprintln!("Successfully cleared cache at `{cache_dir}`.");
         } else {
-            eprintln!(
-                "Cache directory not found at `{}`, nothing to do.",
-                cache_dir
-            );
+            eprintln!("Cache directory not found at `{cache_dir}`, nothing to do.");
         }
     }
 }
@@ -143,17 +149,17 @@ fn update_cache(cache: &Cache, quietly: bool, enable_styles: bool) {
 /// Show file paths
 fn show_paths(config: &Config) {
     let config_dir = get_config_dir().map_or_else(
-        |e| format!("[Error: {}]", e),
+        |e| format!("[Error: {e}]"),
         |(mut path, source)| {
             path.push(""); // Trailing path separator
             match path.to_str() {
-                Some(path) => format!("{} ({})", path, source),
+                Some(path) => format!("{path} ({source})"),
                 None => "[Invalid]".to_string(),
             }
         },
     );
     let config_path = get_config_path().map_or_else(
-        |e| format!("[Error: {}]", e),
+        |e| format!("[Error: {e}]"),
         |(path, _)| path.display().to_string(),
     );
     let cache_dir = config.directories.cache_dir.to_string();
@@ -167,11 +173,11 @@ fn show_paths(config: &Config) {
         Some(ref path_with_source) => path_with_source.to_string(),
         None => "[None]".to_string(),
     };
-    println!("Config dir:       {}", config_dir);
-    println!("Config path:      {}", config_path);
-    println!("Cache dir:        {}", cache_dir);
-    println!("Pages dir:        {}", pages_dir);
-    println!("Custom pages dir: {}", custom_pages_dir);
+    println!("Config dir:       {config_dir}");
+    println!("Config path:      {config_path}");
+    println!("Cache dir:        {cache_dir}");
+    println!("Pages dir:        {pages_dir}");
+    println!("Custom pages dir: {custom_pages_dir}");
 }
 
 /// Create seed config file and exit
@@ -240,7 +246,7 @@ fn main() {
     init_log();
 
     // Parse arguments
-    let args = Args::parse();
+    let args = Cli::parse();
 
     // Determine the usage of styles
     #[cfg(target_os = "windows")]
@@ -255,7 +261,7 @@ fn main() {
         // * NO_COLOR env var isn't set: https://no-color.org/
         // * The output stream is stdout (not being piped)
         ColorOptions::Auto => {
-            ansi_support && env::var_os("NO_COLOR").is_none() && atty::is(Stream::Stdout)
+            ansi_support && env::var_os("NO_COLOR").is_none() && io::stdout().is_terminal()
         }
         // Disable styling
         ColorOptions::Never => false,
@@ -280,8 +286,11 @@ fn main() {
         create_config_and_exit(enable_styles);
     }
 
-    // Specify target OS
-    let platform: PlatformType = args.platform.unwrap_or_else(PlatformType::current);
+    let fallback_platforms: &[PlatformType] = &[PlatformType::current()];
+    let platforms = args
+        .platforms
+        .as_ref()
+        .map_or(fallback_platforms, Vec::as_slice);
 
     // If a local file was passed in, render it and exit
     if let Some(file) = args.render {
@@ -295,7 +304,7 @@ fn main() {
     }
 
     // Instantiate cache. This will not yet create the cache directory!
-    let cache = Cache::new(platform, &config.directories.cache_dir.path);
+    let cache = Cache::new(&config.directories.cache_dir.path, enable_styles);
 
     // Clear cache, pass through
     if args.clear_cache {
@@ -325,7 +334,10 @@ fn main() {
             .custom_pages_dir
             .as_ref()
             .map(PathWithSource::path);
-        println!("{}", cache.list_pages(custom_pages_dir).join("\n"));
+        println!(
+            "{}",
+            cache.list_pages(custom_pages_dir, platforms).join("\n")
+        );
         process::exit(0);
     }
 
@@ -350,6 +362,7 @@ fn main() {
                 .custom_pages_dir
                 .as_ref()
                 .map(PathWithSource::path),
+            platforms,
         ) {
             if let Err(ref e) =
                 print_page(&lookup_result, args.raw, enable_styles, args.pager, &config)
