@@ -2,7 +2,6 @@
 
 use std::{fmt, str};
 
-use anyhow::{anyhow, Result};
 use serde_derive::{Deserialize, Serialize};
 
 #[derive(Debug, Eq, PartialEq, Copy, Clone, Serialize, Deserialize)]
@@ -11,9 +10,12 @@ use serde_derive::{Deserialize, Serialize};
 pub enum PlatformType {
     Linux,
     OsX,
-    SunOs,
     Windows,
+    SunOs,
     Android,
+    FreeBsd,
+    NetBsd,
+    OpenBsd,
 }
 
 impl fmt::Display for PlatformType {
@@ -21,27 +23,40 @@ impl fmt::Display for PlatformType {
         match self {
             Self::Linux => write!(f, "Linux"),
             Self::OsX => write!(f, "macOS / BSD"),
-            Self::SunOs => write!(f, "SunOS"),
             Self::Windows => write!(f, "Windows"),
+            Self::SunOs => write!(f, "SunOS"),
             Self::Android => write!(f, "Android"),
+            Self::FreeBsd => write!(f, "FreeBSD"),
+            Self::NetBsd => write!(f, "NetBSD"),
+            Self::OpenBsd => write!(f, "OpenBSD"),
         }
     }
 }
 
-impl str::FromStr for PlatformType {
-    type Err = anyhow::Error;
+impl clap::ValueEnum for PlatformType {
+    fn value_variants<'a>() -> &'a [Self] {
+        &[
+            Self::Linux,
+            Self::OsX,
+            Self::SunOs,
+            Self::Windows,
+            Self::Android,
+            Self::FreeBsd,
+            Self::NetBsd,
+            Self::OpenBsd,
+        ]
+    }
 
-    fn from_str(s: &str) -> Result<Self, Self::Err> {
-        match s {
-            "linux" => Ok(Self::Linux),
-            "osx" | "macos" => Ok(Self::OsX),
-            "sunos" => Ok(Self::SunOs),
-            "windows" => Ok(Self::Windows),
-            "android" => Ok(Self::Android),
-            other => Err(anyhow!(
-                "Unknown OS: {}. Possible values: linux, macos, osx, sunos, windows, android",
-                other
-            )),
+    fn to_possible_value<'a>(&self) -> Option<clap::builder::PossibleValue> {
+        match self {
+            Self::Linux => Some(clap::builder::PossibleValue::new("linux")),
+            Self::OsX => Some(clap::builder::PossibleValue::new("macos").alias("osx")),
+            Self::Windows => Some(clap::builder::PossibleValue::new("windows")),
+            Self::SunOs => Some(clap::builder::PossibleValue::new("sunos")),
+            Self::Android => Some(clap::builder::PossibleValue::new("android")),
+            Self::FreeBsd => Some(clap::builder::PossibleValue::new("freebsd")),
+            Self::NetBsd => Some(clap::builder::PossibleValue::new("netbsd")),
+            Self::OpenBsd => Some(clap::builder::PossibleValue::new("openbsd")),
         }
     }
 }
@@ -52,13 +67,7 @@ impl PlatformType {
         Self::Linux
     }
 
-    #[cfg(any(
-        target_os = "macos",
-        target_os = "freebsd",
-        target_os = "netbsd",
-        target_os = "openbsd",
-        target_os = "dragonfly"
-    ))]
+    #[cfg(any(target_os = "macos", target_os = "dragonfly"))]
     pub fn current() -> Self {
         Self::OsX
     }
@@ -73,6 +82,21 @@ impl PlatformType {
         Self::Android
     }
 
+    #[cfg(target_os = "freebsd")]
+    pub fn current() -> Self {
+        Self::FreeBsd
+    }
+
+    #[cfg(target_os = "netbsd")]
+    pub fn current() -> Self {
+        Self::NetBsd
+    }
+
+    #[cfg(target_os = "openbsd")]
+    pub fn current() -> Self {
+        Self::OpenBsd
+    }
+
     #[cfg(not(any(
         target_os = "linux",
         target_os = "macos",
@@ -88,7 +112,7 @@ impl PlatformType {
     }
 }
 
-#[derive(Debug, Eq, PartialEq, Copy, Clone, Deserialize)]
+#[derive(Debug, Eq, PartialEq, Copy, Clone, Deserialize, clap::ValueEnum)]
 #[serde(rename_all = "lowercase")]
 pub enum ColorOptions {
     Always,
@@ -96,22 +120,6 @@ pub enum ColorOptions {
     Never,
 }
 
-impl str::FromStr for ColorOptions {
-    type Err = anyhow::Error;
-
-    fn from_str(s: &str) -> Result<Self> {
-        match s {
-            "always" => Ok(Self::Always),
-            "auto" => Ok(Self::Auto),
-            "never" => Ok(Self::Never),
-            other => Err(anyhow!(
-                "Unknown color option: {}. Possible values: always, auto, never",
-                other
-            )),
-        }
-    }
-}
-
 impl Default for ColorOptions {
     fn default() -> Self {
         Self::Auto
